# Rustuya

[![Crates.io](https://img.shields.io/crates/v/rustuya.svg)](https://crates.io/crates/rustuya)
[![Documentation](https://docs.rs/rustuya/badge.svg)](https://docs.rs/rustuya)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

Rustuya is a Rust implementation of the Tuya Local API. It enables local control and monitoring of Tuya-compatible devices without cloud dependencies.

[Guide](https://3735943886.github.io/rustuya/)

## License

MIT
